pygeai.tests.snippets.lab.processes package
===========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.tests.snippets.lab.processes.jobs
   pygeai.tests.snippets.lab.processes.kbs

Submodules
----------

pygeai.tests.snippets.lab.processes.create\_process module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.processes.create_process
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.processes.create\_task module
-------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.processes.create_task
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.processes.list\_processes module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.processes.list_processes
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.lab.processes
   :members:
   :show-inheritance:
   :undoc-members:
